@@ -46,27 +46,28 @@ macro_rules! assert_command_stderr_eq_as_result {
             Err(msg_with_left_command_and_right_expr!(
                 "assertion failed",
                 "assert_command_stderr_eq!",
-                stringify!($a_command), 
-                stringify!($b_expr), 
-                $a_command.get_program(), 
-                $b_expr, 
-                a_output, 
+                stringify!($a_command),
+                stringify!($b_expr),
+                $a_command.get_program(),
+                $b_expr,
+                a_output,
                 $b_expr
             ))
         } else {
             let a_string = String::from_utf8(a_output.unwrap().stderr).unwrap();
-            if a_string == $b_expr {
+            let b_string = String::from($b_expr);
+            if a_string == b_string {
                 Ok(())
             } else {
                 Err(msg_with_left_command_and_right_expr!(
                     "assertion failed",
                     "assert_command_stderr_eq!",
-                    stringify!($a_command), 
-                    stringify!($b_expr), 
-                    $a_command.get_program(), 
+                    stringify!($a_command),
+                    stringify!($b_expr),
+                    $a_command.get_program(),
                     $b_expr,
                     a_string,
-                    $b_expr
+                    b_string
                 ))
             }
         }
@@ -157,7 +158,7 @@ macro_rules! assert_command_stderr_eq {
             Ok(()) => (),
             Err(_err) => panic!($($arg)+),
         }
-    });    
+    });
 }
 
 #[cfg(test)]
